==> jc-1.4.0.tar.gz: java/rmi/server/Operation.h <==
// public class java.rmi.server.Operation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a65cc8b517e3b6d0 java_rmi_server_Operation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_Operation_H_
#define _JC_java_rmi_server_Operation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_Operation$sub_refs	_jc_java_rmi_server_Operation$sub_refs;
typedef struct _jc_java_rmi_server_Operation$sub_nonrefs	_jc_java_rmi_server_Operation$sub_nonrefs;
typedef struct _jc_java_rmi_server_Operation$refs	_jc_java_rmi_server_Operation$refs;
typedef struct _jc_java_rmi_server_Operation$nonrefs	_jc_java_rmi_server_Operation$nonrefs;
typedef struct _jc_java_rmi_server_Operation$object	_jc_java_rmi_server_Operation$object;

typedef const struct _jc_java_rmi_server_Operation$vmethods	_jc_java_rmi_server_Operation$vmethods;
typedef const struct _jc_java_rmi_server_Operation$vtable	_jc_java_rmi_server_Operation$vtable;
typedef const struct _jc_java_rmi_server_Operation$vtype	_jc_java_rmi_server_Operation$vtype;

// Constructors
extern void _jc_java_rmi_server_Operation$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_Operation$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_Operation$method$getOperation$b16cb1edf764ce94(_jc_env *, struct _jc_java_rmi_server_Operation$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_Operation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_Operation$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_Operation$method_info$getOperation$b16cb1edf764ce94;
extern _jc_method _jc_java_rmi_server_Operation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_server_Operation$vmethods {
	struct _jc_java_lang_String$object	*(*getOperation$b16cb1edf764ce94)(_jc_env *, struct _jc_java_rmi_server_Operation$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_Operation$object *);
};

// Vtable
struct _jc_java_rmi_server_Operation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_Operation$vmethods	java_rmi_server_Operation;
};

// Vtype
struct _jc_java_rmi_server_Operation$vtype {
	_jc_type			type;
	_jc_java_rmi_server_Operation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_Operation$sub_refs {
	struct _jc_java_lang_String$object	*operation;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_Operation$refs {
    _jc_java_rmi_server_Operation$sub_refs	java_rmi_server_Operation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_Operation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_Operation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_Operation$sub_nonrefs	java_rmi_server_Operation;
};

// Object instance structure
struct _jc_java_rmi_server_Operation$object {
	_jc_java_rmi_server_Operation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_Operation$vtype	*vtype;
	_jc_java_rmi_server_Operation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_Operation$vtype _jc_java_rmi_server_Operation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_Operation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_Operation$class_object;

#endif	/* _JC_java_rmi_server_Operation_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/Operation.h <==
// public class java.rmi.server.Operation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a65cc8b517e3b6d0 java_rmi_server_Operation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_Operation_H_
#define _JC_java_rmi_server_Operation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_Operation$sub_refs	_jc_java_rmi_server_Operation$sub_refs;
typedef struct _jc_java_rmi_server_Operation$sub_nonrefs	_jc_java_rmi_server_Operation$sub_nonrefs;
typedef struct _jc_java_rmi_server_Operation$refs	_jc_java_rmi_server_Operation$refs;
typedef struct _jc_java_rmi_server_Operation$nonrefs	_jc_java_rmi_server_Operation$nonrefs;
typedef struct _jc_java_rmi_server_Operation$object	_jc_java_rmi_server_Operation$object;

typedef const struct _jc_java_rmi_server_Operation$vmethods	_jc_java_rmi_server_Operation$vmethods;
typedef const struct _jc_java_rmi_server_Operation$vtable	_jc_java_rmi_server_Operation$vtable;
typedef const struct _jc_java_rmi_server_Operation$vtype	_jc_java_rmi_server_Operation$vtype;

// Constructors
extern void _jc_java_rmi_server_Operation$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_Operation$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_Operation$method$getOperation$b16cb1edf764ce94(_jc_env *, struct _jc_java_rmi_server_Operation$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_Operation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_Operation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_Operation$method_info$getOperation$b16cb1edf764ce94;
extern _jc_method _jc_java_rmi_server_Operation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_server_Operation$vmethods {
	struct _jc_java_lang_String$object	*(*getOperation$b16cb1edf764ce94)(_jc_env *, struct _jc_java_rmi_server_Operation$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_Operation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_Operation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_Operation$vmethods	java_rmi_server_Operation;
};

// Vtype
struct _jc_java_rmi_server_Operation$vtype {
	_jc_type			type;
	_jc_java_rmi_server_Operation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_Operation$sub_refs {
	struct _jc_java_lang_String$object	*operation;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_Operation$refs {
    _jc_java_rmi_server_Operation$sub_refs	java_rmi_server_Operation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_Operation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_Operation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_Operation$sub_nonrefs	java_rmi_server_Operation;
};

// Object instance structure
struct _jc_java_rmi_server_Operation$object {
	_jc_java_rmi_server_Operation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_Operation$vtype	*vtype;
	_jc_java_rmi_server_Operation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_Operation$vtype _jc_java_rmi_server_Operation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_Operation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_Operation$class_object;

#endif	/* _JC_java_rmi_server_Operation_H_ */
